@@ -35,10 +35,10 @@ module Data.ListLike.Base
     InfiniteListLike(..),
     zip, zipWith, sequence_
     ) where
-import Prelude hiding (length, uncons, head, last, null, tail, map, filter, concat,
+import Prelude hiding (length, {-uncons,-} head, last, null, tail, map, filter, concat,
                        any, lookup, init, all, foldl, foldr, foldl1, foldr1,
                        maximum, minimum, iterate, span, break, takeWhile,
-                       dropWhile, dropWhileEnd, reverse, zip, zipWith, sequence,
+                       dropWhile, {-dropWhileEnd,-} reverse, zip, zipWith, sequence,
                        sequence_, mapM, mapM_, concatMap, and, or, sum,
                        product, repeat, replicate, cycle, take, drop,
                        splitAt, elem, notElem, unzip, lines, words,
@@ -165,7 +165,7 @@ class (FoldableLL full item, Monoid full) =>
 
     ------------------------------ Special folds
     {- | Flatten the structure. -}
-    concat :: (ListLike full' full, Monoid full) => full' -> full
+    concat :: (ListLike full' full{-, Monoid full-}) => full' -> full
     concat = fold
 
     {- | Map a function over the items and concatenate the results.
@@ -443,14 +443,21 @@ class (FoldableLL full item, Monoid full) =>
 
     ------------------------------ Generalized functions
     {- | Generic version of 'nub' -}
+    -- This code is adapted from Data.List in base.
     nubBy :: (item -> item -> Bool) -> full -> full
-    nubBy f l = nubBy' l (empty :: full)
-     where
-      nubBy' ys xs
-        | null ys              = empty
-        | any (f (head ys)) xs = nubBy' (tail ys) xs
-        | otherwise            = let y = head ys
-                                 in  cons y (nubBy' (tail ys) (cons y xs))
+    nubBy eq l = nubBy' l mempty
+      where
+        nubBy' ys xs =
+          case uncons ys of
+            Nothing -> mempty
+            Just (y, ys')
+              | elem_by y xs -> nubBy' ys' xs
+              | otherwise -> cons y (nubBy' ys' (cons y xs))
+        elem_by :: item -> full -> Bool
+        elem_by y xs =
+          case uncons xs of
+            Nothing -> False
+            Just (x, xs') -> x `eq` y || elem_by y xs'
 {-
     nubBy f l
         | null l = empty
