@@ -1,7 +1,8 @@
-{-# LANGUAGE MultiParamTypeClasses
+{-# LANGUAGE CPP
+            ,MultiParamTypeClasses
             ,FlexibleInstances
             ,TypeSynonymInstances #-}
-
+{-# OPTIONS -fno-warn-orphans #-}
 
 {-
 Copyright (C) 2007 John Goerzen <jgoerzen@complete.org>
@@ -37,6 +38,7 @@ import Prelude hiding (length, head, last, null, tail, map, filter, concat,
                        splitAt, elem, notElem, unzip, lines, words,
                        unlines, unwords)
 import qualified Prelude as P
+import           Control.Applicative ((<$>), (<*>))
 import           Control.Monad
 import qualified Data.List as L
 import qualified Data.Sequence as S
@@ -47,22 +49,22 @@ import           Data.ListLike.String
 import           Data.ListLike.IO
 import           Data.ListLike.FoldableLL
 import           Data.ListLike.Text ()
-import           Data.ListLike.UTF8
+import           Data.ListLike.UTF8 ()
 import           Data.ListLike.Vector ()
 import           Data.Int
-import           Data.Maybe (fromMaybe)
+--import           Data.Maybe (fromMaybe)
 import           Data.Monoid
 import           Data.Semigroup (Semigroup(..))
 import qualified Data.ByteString as BS
 import qualified Data.ByteString.Char8 as BSC
-import qualified Data.Foldable as F
-import qualified Data.Traversable as T
+--import qualified Data.Foldable as F
+--import qualified Data.Traversable as T
 import qualified Data.Array.IArray as A
 import           Data.Array.IArray((!), (//), Ix(..))
 import qualified Data.ByteString.Lazy as BSL
 import qualified Data.ByteString.Lazy.Char8 as BSLC
-import           Data.String.UTF8 (UTF8)
-import qualified Data.String.UTF8 as UTF8
+--import           Data.String.UTF8 (UTF8)
+--import qualified Data.String.UTF8 as UTF8
 import qualified System.IO as IO
 import           Data.Word
 
@@ -75,8 +77,10 @@ import           Data.Word
 instance ListLikeIO String Char where
     hGetLine = IO.hGetLine
     hGetContents = IO.hGetContents
-    hGet h c = BSL.hGet h c >>= (return . toString)
-    hGetNonBlocking h i = BSL.hGetNonBlocking h i >>= (return . toString)
+    hGet _ c | c <= 0 = return mempty
+    hGet h c = cons <$> IO.hGetChar h <*> hGet h (pred c)
+    -- hGetNonBlocking h i >>= (return . toString)
+    hGetNonBlocking _h _i = error "Unimplemented: hGetNonBlocking in instance ListLikeIO String Char"
     hPutStr = IO.hPutStr
     hPutStrLn = IO.hPutStrLn
     getLine = IO.getLine
@@ -87,6 +91,24 @@ instance ListLikeIO String Char where
     readFile = IO.readFile
     writeFile = IO.writeFile
 
+{-
+import           Data.ByteString.Internal (createAndTrim)
+import qualified System.IO.Error as IO
+
+hGetNonBlocking :: IO.Handle -> Int -> IO BS.ByteString
+hGetNonBlocking h i
+    | i >  0    = createAndTrim i $ \p -> IO.hGetBufNonBlocking h p i
+    | i == 0    = return empty
+    | otherwise = illegalBufferSize h "hGetNonBlocking'" i
+
+illegalBufferSize :: IO.Handle -> String -> Int -> IO a
+illegalBufferSize handle fn sz =
+    ioError (IO.mkIOError IO.illegalOperationErrorType msg (Just handle) Nothing)
+    --TODO: System.IO uses InvalidArgument here, but it's not exported :-(
+    where
+      msg = fn ++ ": illegal ByteString size " ++ showsPrec 9 sz []
+-}
+
 instance StringLike String where
     toString = id
     fromString = id
@@ -199,9 +221,18 @@ instance ListLikeIO BS.ByteString Word8 where
     writeFile = BS.writeFile
     appendFile = BS.appendFile
 
+-- There is no bijection between Strings and ByteStrings that I know
+-- of.  The elements of a String are Unicode code points, and while
+-- every String can be UTF8-encoded into a ByteString, there are
+-- ByteStrings that can not be decoded into valid Strings - notably
+-- "\128".  So should ByteString be an instance of StringLike?
+-- Probably not.  Unfortunately, this instance is used to implement
+-- the ListLikeIO instance for String!  This must not stand.
+#if 0
 instance StringLike BS.ByteString where
-    toString = map (toEnum . fromIntegral) . BS.unpack
-    fromString = BS.pack . map (fromIntegral . fromEnum)
+    toString = BSU.toString
+    fromString = BSU.fromString
+#endif
 
 --------------------------------------------------
 -- ByteString.Lazy
@@ -315,9 +346,11 @@ instance ListLikeIO BSL.ByteString Word8 where
     writeFile = BSL.writeFile
     appendFile = BSL.appendFile
 
+#if 0
 instance StringLike BSL.ByteString where
-    toString = map (toEnum . fromIntegral) . BSL.unpack
-    fromString = BSL.pack . map (fromIntegral . fromEnum)
+    toString = BSLU.toString
+    fromString = BSLU.fromString
+#endif
 
 --------------------------------------------------
 -- Map
@@ -332,7 +365,8 @@ instance StringLike BSL.ByteString where
 --------------------------------------------------
 -- Arrays
 
-instance (Ix i) => FoldableLL (A.Array i e) e where
+-- This constraint is required for ghc < 8
+instance Ix i => FoldableLL (A.Array i e) e where
     foldl = F.foldl
     foldl1 = F.foldl1
     foldl' = F.foldl'
