@@ -1,5 +1,6 @@
 {-# LANGUAGE MultiParamTypeClasses
             ,FlexibleInstances #-}
+{-# OPTIONS -fno-warn-orphans #-}
 
 module Data.ListLike.Vector.Unboxed ()
 
@@ -84,12 +85,14 @@ instance StringLike (V.Vector Char) where
     unwords = let sp = V.singleton ' ' in V.concat . intersperse sp . toList
     unlines = let eol = V.singleton '\n' in V.concat . intersperse eol . toList
 
+isPrefixOf' :: (Unbox a, Eq a) => V.Vector a -> V.Vector a -> Bool
 isPrefixOf' needle haystack
   | V.null needle = True
   | V.length needle < V.length haystack =
             needle == V.slice 0 (V.length needle) haystack
   | V.length needle == V.length haystack = needle == haystack
   | otherwise = False
+isSuffixOf' :: (Unbox a, Eq a) => V.Vector a -> V.Vector a -> Bool
 isSuffixOf' needle haystack
   | V.null needle = True
   | V.length needle < V.length haystack =
